# yomari

Yomari is a natural language toolkit distributed as a Python package especially targeting Nepali language.

## Installation

You can install **yomari** from [PyPI](https://pypi.org/project/yomari)

```bash
$ pip install yomari
```

Yomari is supported on Python 3.7 and above.

> ** Note: Active development on the toolkit is being carried out.